**Example 1: 取消置顶接口**



Input: 

```
tccli cfw ModifyBlockTop --cli-unfold-argument  \
    --OpeType xx \
    --UniqueId xx
```

Output: 
```
{
    "Response": {
        "RequestId": "xx"
    }
}
```

